/**
 * Copyright IBM Corporation 2018
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 **/

import Foundation

/** ConsumptionPreferencesCategory. */
public struct ConsumptionPreferencesCategory: Decodable {

    /**
     The unique, non-localized identifier of the consumption preferences category to which the results pertain. IDs have
     the form `consumption_preferences_{category}`.
     */
    public var consumptionPreferenceCategoryID: String

    /**
     The user-visible name of the consumption preferences category.
     */
    public var name: String

    /**
     Detailed results inferred from the input text for the individual preferences of the category.
     */
    public var consumptionPreferences: [ConsumptionPreferences]

    // Map each property name to the key that shall be used for encoding/decoding.
    private enum CodingKeys: String, CodingKey {
        case consumptionPreferenceCategoryID = "consumption_preference_category_id"
        case name = "name"
        case consumptionPreferences = "consumption_preferences"
    }

}
